@@ -1,8 +1,8 @@
 """EditorConfig Python Core"""
 
-from versiontools import join_version
+from editorconfig.versiontools import join_version
 
-VERSION = (0, 11, 0, "final")
+VERSION = (0, 11, 1, "final")
 
 __all__ = ['get_properties', 'EditorConfigError', 'exceptions']
 
@@ -15,5 +15,5 @@ def get_properties(filename):
     return handler.get_configurations()
 
 
-from handler import EditorConfigHandler
-from exceptions import *
+from editorconfig.handler import EditorConfigHandler
+from editorconfig.exceptions import *
